/*
 * File: PWM_TZ_ISR_perinit.c
 * Date: 2024/09/02
 * Version: UNRELEASE
 * Description: This file is released on TI E2E forum for PWM TZ ISR debugging usage
 * DO NOT DISTRIBUTE TO OTHER PLACE
 * Copyright (C) 2024 JohnsonCL Chen <johnson35762@gmail.com>
 */

#include <PWM_TZ_ISR_main.h>

extern __interrupt void ADCINT1_ISR (void);
extern __interrupt void Epwm1_TZ_ISR(void);
extern __interrupt void Timer2_ISR (void);


void Timer_init(void)
{
    EALLOW;
    // initialize CPU timer1 as 1kHz counter, timer2 as 100Hz for updating LED indicator
    InitCpuTimers();
    ConfigCpuTimer(&CpuTimer2, 100, 100000);
    CpuTimer2Regs.TCR.bit.TSS = 1; // Freeze CpuTimer2
    EDIS;
}

void GPIO_init(void)
{
    // Initialize GPIO and configure the GPIO pin as a push-pull output
    InitGpio();

    GPIO_SetupPinMux(GPIO_LED1, GPIO_MUX_CPU1, 0);
    GPIO_SetupPinOptions(GPIO_LED1, GPIO_OUTPUT, GPIO_PUSHPULL);

    GPIO_SetupPinMux(GPIO_LED2, GPIO_MUX_CPU1, 0);
    GPIO_SetupPinOptions(GPIO_LED2, GPIO_OUTPUT, GPIO_PUSHPULL);

    GPIO_SetupPinMux(GPIO_LED3, GPIO_MUX_CPU1, 0);
    GPIO_SetupPinOptions(GPIO_LED3, GPIO_OUTPUT, GPIO_PUSHPULL);

    GPIO_SetupPinMux(GPIO_LED4, GPIO_MUX_CPU1, 0);
    GPIO_SetupPinOptions(GPIO_LED4, GPIO_OUTPUT, GPIO_PUSHPULL);

    GPIO_SetupPinMux(GPIO_LED5, GPIO_MUX_CPU1, 0);
    GPIO_SetupPinOptions(GPIO_LED5, GPIO_OUTPUT, GPIO_PUSHPULL);

    GPIO_SetupPinMux(GPIO_RSVD, GPIO_MUX_CPU1, 0);
    GPIO_SetupPinOptions(GPIO_RSVD, GPIO_OUTPUT, GPIO_PUSHPULL);

}

void ADC_init(void)
{

    SetVREF(ADC_ADCA, ADC_INTERNAL, ADC_VREF3P3);

    EALLOW;

    // ADCA setup
    // Set ADCCLK divider to /1
    AdcaRegs.ADCCTL2.bit.PRESCALE = 0;
    // Set pulse positions to late
    AdcaRegs.ADCCTL1.bit.INTPULSEPOS = 1;
    // Power up the ADC
    AdcaRegs.ADCCTL1.bit.ADCPWDNZ = 1;

    // -----------------------------------------------
    // ADCA SOC setup
    // SOC priority is as default: SOC0 is the highest, round bobbin

    AdcaRegs.ADCSOC0CTL.bit.CHSEL = 0;  // SOC0 will convert pin A0
    AdcaRegs.ADCSOC1CTL.bit.CHSEL = 1;  // SOC1 will convert pin A1
    AdcaRegs.ADCSOC2CTL.bit.CHSEL = 3;  // SOC2 will convert pin A3
    AdcaRegs.ADCSOC3CTL.bit.CHSEL = 5;  // SOC3 will convert pin A5
    AdcaRegs.ADCSOC4CTL.bit.CHSEL = 6;  // SOC4 will convert pin A6
    AdcaRegs.ADCSOC5CTL.bit.CHSEL = 7;  // SOC5 will convert pin A7
    AdcaRegs.ADCSOC6CTL.bit.CHSEL = 9;  // SOC6 will convert pin A9
    AdcaRegs.ADCSOC7CTL.bit.CHSEL = 11; // SOC6 will convert pin A11
    AdcaRegs.ADCSOC8CTL.bit.CHSEL = 12; // SOC6 will convert pin A12

    AdcaRegs.ADCSOC0CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC1CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC2CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC3CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC4CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC5CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC6CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC7CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles
    AdcaRegs.ADCSOC8CTL.bit.ACQPS = 9; // Sample window is 10 SYSCLK cycles

    AdcaRegs.ADCSOC0CTL.bit.TRIGSEL = 9; // SOC0 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC1CTL.bit.TRIGSEL = 9; // SOC1 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC2CTL.bit.TRIGSEL = 9; // SOC2 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC3CTL.bit.TRIGSEL = 9; // SOC3 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC4CTL.bit.TRIGSEL = 9; // SOC4 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC5CTL.bit.TRIGSEL = 9; // SOC5 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC6CTL.bit.TRIGSEL = 9; // SOC6 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC7CTL.bit.TRIGSEL = 9; // SOC7 trigger on ePWM3 SOCA
    AdcaRegs.ADCSOC8CTL.bit.TRIGSEL = 9; // SOC8 trigger on ePWM3 SOCA

    AdcaRegs.ADCINTSEL1N2.bit.INT1SEL = 0; // End of SOC4 will set INT1 flag
    AdcaRegs.ADCINTSEL1N2.bit.INT1E = 1;   // Enable INT1 flag
    AdcaRegs.ADCINTFLGCLR.bit.ADCINT1 = 1; // Make sure INT1 flag is cleared

    EDIS;
}

void EPWM_init(void)
{

    EALLOW;
    CpuSysRegs.PCLKCR0.bit.TBCLKSYNC = 0;           // EPWM time base clock sync reset

    // EPWM1 setup for CMPSS interrupt
    EPwm1Regs.TBCTR = 0;                            // Reset counter
    EPwm1Regs.TBCTL.bit.CLKDIV = TB_DIV1;			// divide by 1

    EPwm1Regs.TBPRD = 10000;        	// Set EPWM1 frequency 10kHz
    EPwm1Regs.CMPA.bit.CMPA = 5000 - 1; // Set CMPB = 50%

    EPwm1Regs.AQCTLA.bit.ZRO = AQ_CLEAR; // EPWMB CLEAR
    EPwm1Regs.AQCTLA.bit.CAU = AQ_SET; 	 // EPWMB SET
    EPwm1Regs.AQCTLB.bit.ZRO = AQ_SET;   // EPWMB SET
    EPwm1Regs.AQCTLB.bit.CAU = AQ_CLEAR; // EPWMB CLEAR

    // DC setup
    EPwm1Regs.DCTRIPSEL.bit.DCAHCOMPSEL = DC_TRIPIN9;	// DCAH connect to trip9
    EPwm1Regs.DCTRIPSEL.bit.DCALCOMPSEL = DC_TRIPIN5;	// DCAL connect to trip5

    EPwm1Regs.DCTRIPSEL.bit.DCBHCOMPSEL = DC_TRIPIN8;	// DCBH connect to trip8
    EPwm1Regs.DCTRIPSEL.bit.DCBLCOMPSEL = DC_TRIPIN4;	// DCBL connect to trip4

    EPwm1Regs.DCACTL.bit.EVT1FRCSYNCSEL = DC_EVT_ASYNC;    // DCA event1 takes async path
    EPwm1Regs.DCACTL.bit.EVT2FRCSYNCSEL = DC_EVT_ASYNC;    // DCA event2 takes async path
    EPwm1Regs.DCBCTL.bit.EVT1FRCSYNCSEL = DC_EVT_ASYNC;    // DCB event1 takes async path
    EPwm1Regs.DCBCTL.bit.EVT2FRCSYNCSEL = DC_EVT_ASYNC;    // DCB event2 takes async path

    EPwm1Regs.DCACTL.bit.EVT1SRCSEL = DC_EVT1;	// DCA event1 takes non-filtered path
    EPwm1Regs.DCACTL.bit.EVT2SRCSEL = DC_EVT2;	// DCA event2 takes non-filtered path
    EPwm1Regs.DCBCTL.bit.EVT1SRCSEL = DC_EVT1;	// DCB event1 takes non-filtered path
    EPwm1Regs.DCBCTL.bit.EVT2SRCSEL = DC_EVT2;	// DCB event1 takes non-filtered path

    // TZ setup
    EPwm1Regs.TZSEL.bit.DCAEVT1 = TZ_ENABLE;
    EPwm1Regs.TZSEL.bit.DCAEVT2 = TZ_DISABLE;
    EPwm1Regs.TZSEL.bit.DCBEVT1 = TZ_DISABLE;
    EPwm1Regs.TZSEL.bit.DCBEVT2 = TZ_DISABLE;

    EPwm1Regs.TZDCSEL.bit.DCAEVT1 = TZ_DCAH_HI;
    EPwm1Regs.TZDCSEL.bit.DCAEVT2 = TZ_DCAL_HI;
    EPwm1Regs.TZDCSEL.bit.DCBEVT1 = TZ_DCBH_HI;
    EPwm1Regs.TZDCSEL.bit.DCBEVT2 = TZ_DCBL_HI;

    EPwm1Regs.TZCTL.bit.DCAEVT1 = TZ_FORCE_HI;  // Force EPWM3A low when DCAEVT1 occur
    EPwm1Regs.TZCTL.bit.DCAEVT2 = TZ_FORCE_LO;  // Force EPWM3A low when DCAEVT2 occur
    EPwm1Regs.TZCTL.bit.DCBEVT1 = TZ_FORCE_HI;  // Force EPWM3B low when DCBEVT1 occur
    EPwm1Regs.TZCTL.bit.DCBEVT2 = TZ_FORCE_LO;  // Force EPWM3B low when DCBEVT2 occur

    EPwm1Regs.TZEINT.bit.OST    = TZ_ENABLE;   // Disable OST interrupt
    											// this should enable after interrupt been enabled

    EPwm1Regs.TZCLR.bit.OST     = 1;            // Clear DCAEVT1 flag

    EPwm1Regs.TBCTL.bit.FREE_SOFT = 2; // Set pwm to free run mode

    EPwm1Regs.TBCTL.bit.CTRMODE = TB_COUNT_UP;   // up count mode


    // EPWM3 setup for triggering ADC convert
    EPwm3Regs.TBCTR = 0;                            // Reset counter
    EPwm3Regs.TBCTL.bit.CLKDIV = 5;				// divide by 32
    EPwm3Regs.TBCTL.bit.HSPCLKDIV = 5;			// divide by 10

    EPwm3Regs.TBPRD = 3125 - 1;        	// Set EPWM3 frequency 100Hz
    EPwm3Regs.CMPA.bit.CMPA = 1562; // Set CMPA = 50%

    EPwm3Regs.AQCTLA.bit.ZRO = AQ_SET;   // EPWMA SET
    EPwm3Regs.AQCTLA.bit.CAU = AQ_CLEAR; // EPWMA CLEAR

    EPwm3Regs.ETSEL.bit.SOCAEN  = 1;  // Enable SOC on A group
    EPwm3Regs.ETSEL.bit.SOCASEL = ET_CTRU_CMPA; // Select SOC on up-count
    EPwm3Regs.ETPS.bit.SOCAPRD  = ET_1ST;  // Generate pulse on 1st event

    EPwm3Regs.TBCTL.bit.FREE_SOFT = 2; // Set pwm to free run mode

    EPwm3Regs.TBCTL.bit.CTRMODE = TB_COUNT_UP;   // up count mode

    CpuSysRegs.PCLKCR0.bit.TBCLKSYNC =1;            // EPWM time base clock sync release

    EDIS;
}


void Interrupt_init()
{
    // Initialize PIE and clear PIE registers. Disables CPU interrupts.
    DINT;
    InitPieCtrl();
    IER = 0x0000;
    IFR = 0x0000;

    // Initialize the PIE vector table with pointers to the shell Interrupt
    // Service Routines (ISR).
    InitPieVectTable();

    // Interrupt setup

    EALLOW;
    PieVectTable.ADCA1_INT  = &ADCINT1_ISR;
    PieVectTable.EPWM1_TZ_INT = &Epwm1_TZ_ISR;
    PieVectTable.TIMER2_INT = &Timer2_ISR;

    PieCtrlRegs.PIEIER1.bit.INTx1 = 1;  // INT1.1 ADCINT A1
    PieCtrlRegs.PIEIER2.bit.INTx1 = 1;  // INT2.1 EPWM1 TZ

    IER |= M_INT1;  // Enable group 1 interrupt (ADCA1)
    IER |= M_INT2;  // Enable group 2 interrupt (EPWM1 TZ, EPWM4 TZ)
    IER |= M_INT14; // Enable INT14 interrupt (Timer2)

    // Write a 0 to this bit to clear it to 0 and clear the interrupt request
    IFR = 0x0000;

    // Writing 1 to the respective interrupt bit clears the bit and enables the PIE block
    PieCtrlRegs.PIEACK.bit.ACK1 = 1;
    PieCtrlRegs.PIEACK.bit.ACK2 = 1;
    PieCtrlRegs.PIEACK.bit.ACK4 = 1;
    PieCtrlRegs.PIEACK.bit.ACK8 = 1;
    PieCtrlRegs.PIEACK.bit.ACK9 = 1;

    CpuTimer2Regs.TCR.bit.TRB = 1; // Reload CPUtimer2
    CpuTimer2Regs.TCR.bit.TSS = 0; // start timer2
    CpuTimer2Regs.TCR.bit.TIF = 1; // Clear timer overflow flag
    CpuTimer2Regs.TCR.bit.TIE = 1; // Enable CPU-Timer Interrupt


    // kick start all interrupt peripherals

    EDIS;

    EINT; // Enable Global interrupt INTM
    ERTM; // Enable Global real time interrupt DBGM
}

void CMPSS_init(void)
{

    EALLOW;

     // Cmpss1 configuration
     Cmpss1Regs.COMPCTL.bit.COMPDACE     = 1;        // Enable CMPSS1 DAC

     // Cmpss1 Analog pin connection
     AnalogSubsysRegs.CMPHPMXSEL.bit.CMP1HPMXSEL = 4;// Connect CMP1 High Positive
     AnalogSubsysRegs.CMPLPMXSEL.bit.CMP1LPMXSEL = 2;// Connect CMP1 Low Positive

     Cmpss1Regs.COMPDACCTL.bit.SWLOADSEL = 0;        // DACxVALS update from SYSCLK, 1 = on EPWMSYNCPER
     Cmpss1Regs.COMPDACCTL.bit.DACSOURCE = 0;        // DAC source update from DACHVALS(high value shadow register), 1 = ramp generator
     Cmpss1Regs.COMPDACCTL.bit.SELREF    = 0;        // DAC reference select to VDDA, 1 = VDAC

     // Cmpss1 High comparator setup
     Cmpss1Regs.DACHVALS.bit.DACVAL      = 1000;
     Cmpss1Regs.COMPCTL.bit.COMPHSOURCE  = 0;        // CMP1 High negative driven by internal DAC, 1=External pin
     Cmpss1Regs.COMPCTL.bit.COMPHINV     = 0;        // CMP1 High not invert, 1 = Invert
     Cmpss1Regs.COMPCTL.bit.CTRIPHSEL    = 0;        // CTRIPH source from ASYNC comparator output, 1 = SYNC CMP output, 2 = digital filter, 3 = Latched output of digital filter

     // Cmpss1 Low comparator setup
     Cmpss1Regs.DACLVALS.bit.DACVAL      = 200;
     Cmpss1Regs.COMPCTL.bit.COMPLSOURCE  = 0;        // CMP1 Low negative driven by internal DAC, 1=External pin
     Cmpss1Regs.COMPCTL.bit.COMPLINV     = 1;        // CMP1 Low invert, 0 = non Invert
     Cmpss1Regs.COMPCTL.bit.CTRIPLSEL    = 0;        // CTRIPL source from ASYNC comparator output, 1 = SYNC CMP output, 2 = digital filter, 3 = Latched output of digital filter


     // Cmpss3 Configuration
     Cmpss3Regs.COMPCTL.bit.COMPDACE     = 1;        // Enable CMPSS3 DAC

     // Cmpss3 Analog pin connection
     AnalogSubsysRegs.CMPHPMXSEL.bit.CMP3HPMXSEL = 1;// Connect CMP3 High Positive

     Cmpss3Regs.COMPDACCTL.bit.SWLOADSEL = 0;        // DACxVALS update from SYSCLK, 1 = on EPWMSYNCPER
     Cmpss3Regs.COMPDACCTL.bit.DACSOURCE = 0;        // DAC source update from DACHVALS(high value shadow register), 1 = ramp generator
     Cmpss3Regs.COMPDACCTL.bit.SELREF    = 0;        // DAC reference select to VDDA, 1 = VDAC

     // Cmpss3 High comparator setup
     Cmpss3Regs.DACHVALS.bit.DACVAL      = 1264;
     Cmpss3Regs.COMPCTL.bit.COMPHSOURCE  = 0;        // CMP3 High negative driven by internal DAC, 1=External pin
     Cmpss3Regs.COMPCTL.bit.COMPHINV     = 1;        // CMP3 High invert, 1 = Invert
     Cmpss3Regs.COMPCTL.bit.CTRIPHSEL    = 0;        // CTRIPH source from ASYNC comparator output, 1 = SYNC CMP output, 2 = digital filter, 3 = Latched output of digital filter

     // Cmpss3 Filter setup
 //    Cmpss3Regs.COMPCTL.bit.CTRIPHSEL = 2;     // Output of digital filter drives CTRIPH -> to EPWM X-BAR

     // CMPSS4-------------------------------------------- //

     // Cmpss4 Configuration
     Cmpss4Regs.COMPCTL.bit.COMPDACE     = 1;        // Enable CMPSS4 DAC

     Cmpss4Regs.COMPDACCTL.bit.SWLOADSEL = 0;        // DACxVALS update from SYSCLK, 1 = on EPWMSYNCPER
     Cmpss4Regs.COMPDACCTL.bit.DACSOURCE = 0;        // DAC source update from DACHVALS(high value shadow register), 1 = ramp generator
     Cmpss4Regs.COMPDACCTL.bit.SELREF    = 0;        // DAC reference select to VDDA, 1 = VDAC


     // Cmpss4 Analog pin connection
     AnalogSubsysRegs.CMPHPMXSEL.bit.CMP4HPMXSEL = 2; // Connect CMP4 High Positive to pin A12
     AnalogSubsysRegs.CMPLPMXSEL.bit.CMP4LPMXSEL = 2; // Connect CMP4 Low Positive to pin A12

     // Cmpss4 Threshold setup
     Cmpss4Regs.DACHVALS.bit.DACVAL      = 3102;
     Cmpss4Regs.DACLVALS.bit.DACVAL      = 2026;


     // Cmpss4 High comparator setup
     Cmpss4Regs.COMPCTL.bit.COMPHSOURCE  = 0;        // CMP4 High negative driven by internal DAC, 1=External pin
     Cmpss4Regs.COMPCTL.bit.COMPHINV     = 0;        // CMP4 High invert, 1 = Invert
     Cmpss4Regs.COMPCTL.bit.CTRIPHSEL    = 0;        // CTRIPH source from ASYNC comparator output, 1 = SYNC CMP output, 2 = digital filter, 3 = Latched output of digital filter

     // Cmpss4 Low comparator setup
	 Cmpss4Regs.COMPCTL.bit.COMPLSOURCE  = 0;        // CMP4 Low negative driven by internal DAC, 1=External pin
	 Cmpss4Regs.COMPCTL.bit.COMPLINV     = 1;        // CMP4 Low invert, 1 = Invert
	 Cmpss4Regs.COMPCTL.bit.CTRIPLSEL    = 0;        // CTRIPL source from ASYNC comparator output, 1 = SYNC CMP output, 2 = digital filter, 3 = Latched output of digital filter

    EDIS;
}

void XBAR_init(){
	EALLOW;
	// Mux map TRM pp.801
    // Trip4 connect to CMPSS1 HIGH
    EPwmXbarRegs.TRIP4MUX0TO15CFG.bit.MUX0 = 0;
    EPwmXbarRegs.TRIP4MUXENABLE.bit.MUX0 = 1;

    // Trip5 connect to CMPSS1 LOW
    EPwmXbarRegs.TRIP5MUX0TO15CFG.bit.MUX1 = 0;
    EPwmXbarRegs.TRIP5MUXENABLE.bit.MUX1 = 1;

    // Trip7 connect to CMPSS3 HIGH
    EPwmXbarRegs.TRIP7MUX0TO15CFG.bit.MUX4 = 0;
    EPwmXbarRegs.TRIP7MUXENABLE.bit.MUX4 = 1;

    // Trip8 connect to CMPSS4 HIGH
	EPwmXbarRegs.TRIP8MUX0TO15CFG.bit.MUX6 = 0;
	EPwmXbarRegs.TRIP8MUXENABLE.bit.MUX6 = 1;

	// Trip9 connect to CMPSS4 LOW
	EPwmXbarRegs.TRIP9MUX0TO15CFG.bit.MUX7 = 0;
	EPwmXbarRegs.TRIP9MUXENABLE.bit.MUX7 = 1;

	EDIS;
}

// EOF
