/*
 * File: PWM_TZ_ISR_perinit.h
 * Date: 2024/09/02
 * Version: UNRELEASE
 * Description: This file is released on TI E2E forum for PWM TZ ISR debugging usage
 * DO NOT DISTRIBUTE TO OTHER PLACE
 * Copyright (C) 2024 JohnsonCL Chen <johnson35762@gmail.com>
 */


#ifndef _PWM_TZ_ISR_PERINIT_H_
#define _PWM_TZ_ISR_PERINIT_H_


/*
 * @brief	Initialize CPU timer1 and timer2
 * The timer is used to provide housekeeping functions include LED, SCI watch dog
 * and meter information exchange.The ISR frequency is 100Hz
 * @param	none
 * @return none
 */
void Timer_init();

/*
 * @brief	Initialize GPIO multiplexer
 * This function initialize the GPIO and peripherals
 * @param	none
 * @return none
 */
void GPIO_init();

/*
 * @brief	Initialize ADC SOC and channel selection
 * All ADC triggered by EPWM3 SOCA signal, 100Hz
 * @param	none
 * @return none
 */
void ADC_init();

/*
 * @brief	Initialize EPWM modules
 * This function initialize the EPWM peripherals,
 * EPWM1 - Is used to generate EPWM-TZ ISR connected to CMPSS module
 * EPWM3 - To generate ADC trigger signal EPWM3-SOCA
 * @param	none
 * @return none
 */
void EPWM_init();


/*
 * @brief	Initialize peripheral interrupts
 * This function specify the ISR function name and set the PIE table
 * @param	none
 * @return none
 */
void Interrupt_init();

/*
 * @brief	Initialize CMPSS module
 * This function initialize the CMPSS and analog sub-system connection
 * @param	none
 * @return none
 */
void CMPSS_init();

/*
 * @brief	Initialize X-BAR connect the CMPSS output to ePWM interrupts
 * This function initialize the X-BAR module
 * @param	none
 * @return	none
 */
void XBAR_init();


#endif
